@@ -1,3 +1,3 @@
 from .utils._api_conn import obtain_reddit_refresh_token
 from .utils._config_io import update_config_file
-from .utils._extract_addresses import CSVExtractor, RedditExtractor, TwitterExtractor
+from .utils._extract_addresses import AddressConverter, CSVExtractor, RedditExtractor, TwitterExtractor
